{# Custom AutoAPI index with scikit-learn style navigation #}
API Reference
=============

This section contains the complete software documentation for FABulous.

.. toctree::
   :maxdepth: 1
   :titlesonly:
   :glob:

   FABulous/index
   FABulous/**/index
